@@ -2023,24 +2023,12 @@ sub _Mask {
         $Param{OptionCustomerUserAddressBook} = 1;
     }
 
-    # build text template string
-    my %StandardTemplates = $Kernel::OM->Get('Kernel::System::StandardTemplate')->StandardTemplateList(
-        Valid => 1,
-        Type  => 'Email',
-    );
-
     my $QueueStandardTemplates = $Self->_GetStandardTemplates(
         %Param,
         TicketID => $Self->{TicketID} || '',
     );
 
-    if (
-        IsHashRefWithData(
-            $QueueStandardTemplates
-                || ( $Param{Queue} && IsHashRefWithData( \%StandardTemplates ) )
-        )
-        )
-    {
+    if ( IsHashRefWithData($QueueStandardTemplates) ) {
         $Param{StandardTemplateStrg} = $LayoutObject->BuildSelection(
             Data         => $QueueStandardTemplates || {},
             Name         => 'StandardTemplateID',
@@ -2421,11 +2409,17 @@ sub _GetExtendedParams {
 sub _GetStandardTemplates {
     my ( $Self, %Param ) = @_;
 
-    # get create templates
-    my %Templates;
+    NEEDED:
+    for my $Needed (qw(QueueID TicketID)) {
 
-    # check needed
-    return \%Templates if !$Param{QueueID} && !$Param{TicketID};
+        next NEEDED if defined $Param{$Needed};
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Parameter '$Needed' is needed!",
+        );
+        return {};
+    }
 
     my $QueueID = $Param{QueueID} || '';
     if ( !$Param{QueueID} && $Param{TicketID} ) {
@@ -2446,7 +2440,7 @@ sub _GetStandardTemplates {
     );
 
     # return empty hash if there are no templates for this screen
-    return \%Templates if !IsHashRefWithData( $StandardTemplates{Email} );
+    return {} if !IsHashRefWithData( $StandardTemplates{Email} );
 
     # return just the templates for this screen
     return $StandardTemplates{Email};
